aboutsummaryrefslogtreecommitdiffstats
path: root/mail/component-factory.c
diff options
context:
space:
mode:
authorJeffrey Stedfast <fejj@ximian.com>2001-02-24 00:51:45 +0800
committerJeffrey Stedfast <fejj@src.gnome.org>2001-02-24 00:51:45 +0800
commitac97d963b038541b84aa15b4eaa3d28fd9d60114 (patch)
treebd75dd9084c6315c49f094e5989ba5741f16e7ef /mail/component-factory.c
parentc06709a5751b39e4a9cbf931759245f6abaa3d53 (diff)
downloadgsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar.gz
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar.bz2
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar.lz
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar.xz
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.tar.zst
gsoc2013-evolution-ac97d963b038541b84aa15b4eaa3d28fd9d60114.zip
No longer need to do a vtrash_cleanup() (it also doesn't exist anymore).
2001-02-23 Jeffrey Stedfast <fejj@ximian.com> * main.c (main): No longer need to do a vtrash_cleanup() (it also doesn't exist anymore). * component-factory.c (mail_load_storages): Updated to use the new vtrash code. (owner_set_cb): Same. * mail-tools.c (mail_tool_uri_to_folder): Update to handle the "vtrash:" url prefix so that we can extract the REAL uri and know to get the trash folder. * mail-vtrash.c (mail_vtrash_add): Add the vTrash folder to the EvolutionStorage. (mail_vtrash_create): Get the store based on the uri (async) and then call mail_trash_add. (vtrash_cleanup): Removed. (vtrash_uri_to_folder): Removed. (vtrash_create): Replaced by mail_vtrash_create() svn path=/trunk/; revision=8367
Diffstat (limited to 'mail/component-factory.c')
-rw-r--r--mail/component-factory.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/mail/component-factory.c b/mail/component-factory.c
index 2c408db446..94945c8ad1 100644
--- a/mail/component-factory.c
+++ b/mail/component-factory.c
@@ -216,7 +216,7 @@ owner_set_cb (EvolutionShellComponent *shell_component,
g_free (uri);
}
- vtrash_create ("file:/", NULL, NULL);
+ mail_vtrash_create ("file:/", _("vTrash"));
mail_session_enable_interaction (TRUE);
@@ -443,8 +443,8 @@ mail_load_storages (GNOME_Evolution_Shell shell, const GSList *sources, gboolean
camel_exception_get_description (&ex));
camel_exception_clear (&ex);
} else {
- /* create the vTrash folder */
- vtrash_create (service->url, NULL, NULL);
+ /* add the vTrash folder */
+ mail_vtrash_add (CAMEL_STORE (store), service->url, _("vTrash"));
}
}